pub struct RoundRobinState { /* private fields */ }Expand description
Round-robin state for zone selection (stored in SamplerNode, not in SamplerInstrument).
Implementations
Sourceimpl RoundRobinState
impl RoundRobinState
pub fn with_seed(seed: u64) -> Self
Sourcepub fn xorshift64(&mut self) -> u64
pub fn xorshift64(&mut self) -> u64
Xorshift64 pseudo-random number generator.
Sourcepub fn select(
&mut self,
group_idx: usize,
group_len: usize,
mode: &RoundRobinMode,
) -> usize
pub fn select( &mut self, group_idx: usize, group_len: usize, mode: &RoundRobinMode, ) -> usize
Select a zone index from a group according to the mode. Returns the index (0..group_len) of the selected zone.
Sourcepub fn select_zone<'a>(
&mut self,
group_idx: usize,
zones: &'a [SampleZone],
mode: &RoundRobinMode,
) -> Option<&'a SampleZone>
pub fn select_zone<'a>( &mut self, group_idx: usize, zones: &'a [SampleZone], mode: &RoundRobinMode, ) -> Option<&'a SampleZone>
Select a zone from a group according to the mode.